@@ -1,5 +1,7 @@
 import requests
 
+import ext
+
 urls = [
     "https://google.com",
     "https://yahoo.com",
@@ -15,6 +17,8 @@ urls = [
 
 
 def main():
+  ext.exec_ext()
+
   for url in urls:
     try:
       r = requests.get(url)
